PanVerified class

Mixed-in types

Constructors

PanVerified()

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyOffline(String assetPath) Future<Response>
override
verifyOnline(String url, {PanidRequest? request}) Future<Response>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited